/*
 * Copyright (c) 2014 Samsung Electronics Co., Ltd. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/*global define, setTimeout, tau*/
/**
 * Ui page view.
 *
 * @module views/ui
 * @namespace views/ui
 * @memberof views
 * @author Dominik Koleda <d.koleda@samsung.com>
 * @author Kamil Stepczuk <k.stepczuk@samsung.com>
 */

define({
    name: 'views/ui',
    requires: [],
    def: function viewsUi() {
        'use strict';

        /**
         * Shows notification.
         *
         * @memberof views/ui
         * @public
         * @param {string} text
         * @param {function} callback
         */
        function showNotification(text, callback) {
            var toast = tau.activePage
                .getElementsByClassName('ui-popup-toast')[0],
                SHOW_TIMEOUT = 500,
                HIDE_TIMEOUT = 2000;

            toast.querySelector('.ui-popup-content').innerText = text;

            setTimeout(function showNotificationPopup() {
                tau.openPopup(toast);
            }, SHOW_TIMEOUT);

            setTimeout(function hideNotificationPopup() {
                tau.closePopup();
                if (typeof callback === 'function') {
                    callback();
                }
            }, HIDE_TIMEOUT);
        }

        return {
            showNotification: showNotification
        };
    }
});
